NLSL: expdat.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Modules | Variables
expdat.f90 File Reference

Go to the source code of this file.

## Modules
module | expdat

## Variables
double precision, dimension(mxpt), save | expdat::data
double precision, dimension(mxinp, 3), save | expdat::spltmp
double precision, dimension(mxspc), save | expdat::rmsn
double precision, dimension(mxspc), save | expdat::sbi
double precision, dimension(mxspc), save | expdat::sdb
double precision, dimension(mxspc), save | expdat::srng
double precision, dimension(mxspc), save | expdat::shft
double precision, dimension(mxspc), save | expdat::sb0
double precision, dimension(mxspc), save | expdat::sphs
double precision, dimension(mxspc), save | expdat::spsi
double precision, dimension(mxspc), save | expdat::slb
double precision, dimension(mxspc), save | expdat::tmpshft
integer, dimension(mxspc), save | expdat::iform
integer, dimension(mxspc), save | expdat::ibase
integer, dimension(mxspc), save | expdat::nft
integer, dimension(mxspc), save | expdat::npts
integer, dimension(mxspc), save | expdat::ishft
integer, dimension(mxspc), save | expdat::idrv
integer, dimension(mxspc), save | expdat::ixsp
integer, dimension(mxspc), save | expdat::nrmlz
integer, save | expdat::nspc
integer, save | expdat::nwin
integer, save | expdat::ndatot
integer, save | expdat::ishglb
integer, save | expdat::inform
integer, save | expdat::bcmode
integer, save | expdat::drmode
integer, save | expdat::nspline
integer, save | expdat::shftflg
integer, save | expdat::normflg
integer, save | expdat::written
character *30, dimension(mxspc), save | expdat::dataid
character *20, dimension(mxspc), save | expdat::wndoid